# autotweet #
Python Auto Tweet

Right now the script is set to loop.  I'll probably add options to either loop at intervals or tweet once so it can be used with cron.


## Twitter App Credentials ##
-copy `env.example.py` to `env.py`
-Get your twitter app credentials and paste them in `env.py`.

## Run ##
`python tweet.py`